<?php
/**
 * The Secret World functions and definitions
 *
 * Sets up the theme and provides some helper functions. Some helper functions
 * are used in the theme as custom template tags. Others are attached to action and
 * filter hooks in WordPress to change core functionality.
 *
 * The first function, thesecretworld_setup(), sets up the theme by registering support
 * for various features in WordPress, such as post thumbnails, navigation menus, and the like.
 *
 * When using a child theme (see http://codex.wordpress.org/Theme_Development and
 * http://codex.wordpress.org/Child_Themes), you can override certain functions
 * (those wrapped in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before the parent
 * theme's file, so the child theme functions would be used.
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are instead attached
 * to a filter or action hook. The hook can be removed by using remove_action() or
 * remove_filter() and you can attach your own function to the hook.
 *
 * We can remove the parent theme's hook only after it is attached, which means we need to
 * wait until setting up the child theme:
 *
 * <code>
 * add_action( 'after_setup_theme', 'my_child_theme_setup' );
 * function my_child_theme_setup() {
 *     // We are providing our own filter for excerpt_length (or using the unfiltered value)
 *     remove_filter( 'excerpt_length', 'thesecretworld_excerpt_length' );
 *     ...
 * }
 * </code>
 *
 * For more information on hooks, actions, and filters, see http://codex.wordpress.org/Plugin_API.
 *
 * @package WordPress
 * @subpackage The_Secret_World
 * @since The Secret World 1.0
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) )
	$content_width = 584;

/**
 * Tell WordPress to run thesecretworld_setup() when the 'after_setup_theme' hook is run.
 */
add_action( 'after_setup_theme', 'thesecretworld_setup' );

if ( ! function_exists( 'thesecretworld_setup' ) ):
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * To override thesecretworld_setup() in a child theme, add your own thesecretworld_setup to your child theme's
 * functions.php file.
 *
 * @uses load_theme_textdomain() For translation/localization support.
 * @uses add_editor_style() To style the visual editor.
 * @uses add_theme_support() To add support for post thumbnails, automatic feed links, and Post Formats.
 * @uses register_nav_menus() To add support for navigation menus.
 * @uses add_custom_background() To add support for a custom background.
 * @uses add_custom_image_header() To add support for a custom header.
 * @uses register_default_headers() To register the default custom header images provided with the theme.
 * @uses set_post_thumbnail_size() To set a custom post thumbnail size.
 *
 * @since The Secret World 1.0
 */
function thesecretworld_setup() {

	/* Make The Secret World available for translation.
	 * Translations can be added to the /languages/ directory.
	 * If you're building a theme based on The Secret World, use a find and replace
	 * to change 'thesecretworld' to the name of your theme in all the template files.
	 */
	load_theme_textdomain( 'thesecretworld', TEMPLATEPATH . '/languages' );

	$locale = get_locale();
	$locale_file = TEMPLATEPATH . "/languages/$locale.php";
	if ( is_readable( $locale_file ) )
		require_once( $locale_file );

	// This theme styles the visual editor with editor-style.css to match the theme style.
	add_editor_style();

	// Load up our theme options page and related code.
	require( dirname( __FILE__ ) . '/inc/theme-options.php' );

	// Grab The Secret World's Ephemera widget.
	require( dirname( __FILE__ ) . '/inc/widgets.php' );

	// Add default posts and comments RSS feed links to <head>.
	add_theme_support( 'automatic-feed-links' );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menu( 'primary', __( 'Primary Menu', 'thesecretworld' ) );

	// Add support for a variety of post formats
	add_theme_support( 'post-formats', array( 'aside', 'link', 'gallery', 'status', 'quote', 'image' ) );

	// Add support for custom backgrounds
	add_custom_background();

	// This theme uses Featured Images (also known as post thumbnails) for per-post/per-page Custom Header images
	add_theme_support( 'post-thumbnails' );

	// The next four constants set how The Secret World supports custom headers.

	// The default header text color
	define( 'HEADER_TEXTCOLOR', '000' );

	// By leaving empty, we allow for random image rotation.
	define( 'HEADER_IMAGE', '' );

	// The height and width of your custom header.
	// Add a filter to thesecretworld_header_image_width and thesecretworld_header_image_height to change these values.
	define( 'HEADER_IMAGE_WIDTH', apply_filters( 'thesecretworld_header_image_width', 95 ) );
	define( 'HEADER_IMAGE_HEIGHT', apply_filters( 'thesecretworld_header_image_height', 93 ) );

	// We'll be using post thumbnails for custom header images on posts and pages.
	// We want them to be the size of the header image that we just defined
	// Larger images will be auto-cropped to fit, smaller ones will be ignored. See header.php.
	set_post_thumbnail_size( HEADER_IMAGE_WIDTH, HEADER_IMAGE_HEIGHT, true );

	// Add The Secret World's custom image sizes
	add_image_size( 'large-feature', HEADER_IMAGE_WIDTH, HEADER_IMAGE_HEIGHT, true ); // Used for large feature (header) images
	add_image_size( 'small-feature', 500, 300 ); // Used for featured posts if a large-feature doesn't exist

	// Turn on random header image rotation by default.
	add_theme_support( 'custom-header', array( 'random-default' => true ) );

	// Add a way for the custom header to be styled in the admin panel that controls
	// custom headers. See thesecretworld_admin_header_style(), below.
	add_custom_image_header( 'thesecretworld_header_style', 'thesecretworld_admin_header_style', 'thesecretworld_admin_header_image' );

	// ... and thus ends the changeable header business.

	// Default custom headers packaged with the theme. %s is a placeholder for the theme template directory URI.
	register_default_headers( array(
		'logo_dragon' => array(
			'url' => '%s/images/logo_dragon.png',
			'thumbnail_url' => '%s/images/logo_dragon.png',
			/* translators: header image description */
			'description' => __( 'Dragon', 'thesecretworld' )
		),
		'logo_illuminati' => array(
			'url' => '%s/images/logo_illuminati.png',
			'thumbnail_url' => '%s/images/logo_illuminati.png',
			/* translators: header image description */
			'description' => __( 'Illuminati', 'thesecretworld' )
		),
		'logo_templars' => array(
			'url' => '%s/images/logo_templars.png',
			'thumbnail_url' => '%s/images/logo_templars.png',
			/* translators: header image description */
			'description' => __( 'Templars', 'thesecretworld' )
		),
	) );
}
endif; // thesecretworld_setup

if ( ! function_exists( 'thesecretworld_header_style' ) ) :
/**
 * Styles the header image and text displayed on the blog
 *
 * @since The Secret World 1.0
 */
function thesecretworld_header_style() {

	// If no custom options for text are set, let's bail
	// get_header_textcolor() options: HEADER_TEXTCOLOR is default, hide text (returns 'blank') or any hex value
	if ( HEADER_TEXTCOLOR == get_header_textcolor() )
		return;
	// If we get this far, we have custom styles. Let's do this.
	?>
	<style type="text/css">
	<?php
		// Has the text been hidden?
		if ( 'blank' == get_header_textcolor() ) :
	?>
		#site-title,
		#site-description {
			position: absolute !important;
			clip: rect(1px 1px 1px 1px); /* IE6, IE7 */
			clip: rect(1px, 1px, 1px, 1px);
		}
	<?php
		// If the user has set a custom color for the text use that
		else :
	?>
		#site-title a,
		#site-description {
			color: #<?php echo get_header_textcolor(); ?> !important;
		}
	<?php endif; ?>
	</style>
	<?php
}
endif; // thesecretworld_header_style

if ( ! function_exists( 'thesecretworld_admin_header_style' ) ) :
/**
 * Styles the header image displayed on the Appearance > Header admin panel.
 *
 * Referenced via add_custom_image_header() in thesecretworld_setup().
 *
 * @since The Secret World 1.0
 */
function thesecretworld_admin_header_style() {
?>
	<style type="text/css">
	.appearance_page_custom-header #headimg {
		border: none;
	}
	#headimg h1,
	#desc {
		font-family: "Helvetica Neue", Arial, Helvetica, "Nimbus Sans L", sans-serif;
	}
	#headimg h1 {
		margin: 0;
	}
	#headimg h1 a {
		font-size: 32px;
		line-height: 36px;
		text-decoration: none;
	}
	#desc {
		font-size: 14px;
		line-height: 23px;
		padding: 0 0 3em;
	}
	<?php
		// If the user has set a custom color for the text use that
		if ( get_header_textcolor() != HEADER_TEXTCOLOR ) :
	?>
		#site-title a,
		#site-description {
			color: #<?php echo get_header_textcolor(); ?>;
		}
	<?php endif; ?>
	#headimg img {
		height: auto;
		width: auto;
	}
	</style>
<?php
}
endif; // thesecretworld_admin_header_style

if ( ! function_exists( 'thesecretworld_admin_header_image' ) ) :
/**
 * Custom header image markup displayed on the Appearance > Header admin panel.
 *
 * Referenced via add_custom_image_header() in thesecretworld_setup().
 *
 * @since The Secret World 1.0
 */
function thesecretworld_admin_header_image() { ?>
	<div id="headimg">
		<?php
		if ( 'blank' == get_theme_mod( 'header_textcolor', HEADER_TEXTCOLOR ) || '' == get_theme_mod( 'header_textcolor', HEADER_TEXTCOLOR ) )
			$style = ' style="display:none;"';
		else
			$style = ' style="color:#' . get_theme_mod( 'header_textcolor', HEADER_TEXTCOLOR ) . ';"';
		?>
		<h1><a id="name"<?php echo $style; ?> onclick="return false;" href="<?php echo esc_url( home_url( '/' ) ); ?>"><?php bloginfo( 'name' ); ?></a></h1>
		<div id="desc"<?php echo $style; ?>><?php bloginfo( 'description' ); ?></div>
		<?php $header_image = get_header_image();
		if ( ! empty( $header_image ) ) : ?>
			<img src="<?php echo esc_url( $header_image ); ?>" alt="" />
		<?php endif; ?>
	</div>
<?php }
endif; // thesecretworld_admin_header_image

/**
 * Sets the post excerpt length to 40 words.
 *
 * To override this length in a child theme, remove the filter and add your own
 * function tied to the excerpt_length filter hook.
 */
function thesecretworld_excerpt_length( $length ) {
	return 40;
}
add_filter( 'excerpt_length', 'thesecretworld_excerpt_length' );

/**
 * Returns a "Continue Reading" link for excerpts
 */
function thesecretworld_continue_reading_link() {
	return ' ';
}

/**
 * Replaces "[...]" (appended to automatically generated excerpts) with an ellipsis and thesecretworld_continue_reading_link().
 *
 * To override this in a child theme, remove the filter and add your own
 * function tied to the excerpt_more filter hook.
 */
function thesecretworld_auto_excerpt_more( $more ) {
	return ' &hellip;' . thesecretworld_continue_reading_link();
}
add_filter( 'excerpt_more', 'thesecretworld_auto_excerpt_more' );

/**
 * Adds a pretty "Continue Reading" link to custom post excerpts.
 *
 * To override this link in a child theme, remove the filter and add your own
 * function tied to the get_the_excerpt filter hook.
 */
function thesecretworld_custom_excerpt_more( $output ) {
	if ( has_excerpt() && ! is_attachment() ) {
		$output .= thesecretworld_continue_reading_link();
	}
	return $output;
}
add_filter( 'get_the_excerpt', 'thesecretworld_custom_excerpt_more' );

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 */
function thesecretworld_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'thesecretworld_page_menu_args' );

/**
 * Register our sidebars and widgetized areas. Also register the default Epherma widget.
 *
 * @since The Secret World 1.0
 */
function thesecretworld_widgets_init() {
	
	unregister_widget('WP_Widget_Links');
	register_widget('HE_Widget_Links');
	unregister_widget('WP_Widget_Recent_Posts');
	register_widget('HE_Widget_Recent_Posts'); // HE version of WP_Widget_Recent_Posts

	register_widget('HE_Widget_Social_Networks');
	register_widget('HE_Widget_Members_online');
	register_widget('HE_Widget_HomeImages');

	register_sidebar( array(
		'name' => __( 'Main Sidebar', 'thesecretworld' ),
		'id' => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => __( 'Footer Area One', 'thesecretworld' ),
		'id' => 'sidebar-3',
		'description' => __( 'An optional widget area for your site footer', 'thesecretworld' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => __( 'Footer Area Two', 'thesecretworld' ),
		'id' => 'sidebar-4',
		'description' => __( 'An optional widget area for your site footer', 'thesecretworld' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => __( 'Footer Area Three', 'thesecretworld' ),
		'id' => 'sidebar-5',
		'description' => __( 'An optional widget area for your site footer', 'thesecretworld' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );

	register_sidebar( array(
		'name' => __( 'Teaser', 'thesecretworld' ),
		'id' => 'sidebar-6',
		'description' => 'An optional widget area at the top of your main content area',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
}
add_action( 'widgets_init', 'thesecretworld_widgets_init' );

/**
 * Display navigation to next/previous pages when applicable
 */
function thesecretworld_content_nav( $nav_id ) {
	global $wp_query;

	if ( $wp_query->max_num_pages > 1 ) : ?>
		<nav id="<?php echo $nav_id; ?>">
			<h3 class="assistive-text"><?php _e( 'Post navigation', 'thesecretworld' ); ?></h3>
			<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&lt;</span> Older posts', 'thesecretworld' ) ); ?></div>
			<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&gt;</span>', 'thesecretworld' ) ); ?></div>
		</nav><!-- #nav-above -->
	<?php endif;
}

/**
 * Return the URL for the first link found in the post content.
 *
 * @since The Secret World 1.0
 * @return string|bool URL or false when no link is present.
 */
function thesecretworld_url_grabber() {
	if ( ! preg_match( '/<a\s[^>]*?href=[\'"](.+?)[\'"]/is', get_the_content(), $matches ) )
		return false;

	return esc_url_raw( $matches[1] );
}

/**
 * Count the number of footer sidebars to enable dynamic classes for the footer
 */
function thesecretworld_footer_sidebar_class() {
	$count = 0;

	if ( is_active_sidebar( 'sidebar-3' ) )
		$count++;

	if ( is_active_sidebar( 'sidebar-4' ) )
		$count++;

	if ( is_active_sidebar( 'sidebar-5' ) )
		$count++;

	$class = '';

	switch ( $count ) {
		case '1':
			$class = 'one';
			break;
		case '2':
			$class = 'two';
			break;
		case '3':
			$class = 'three';
			break;
	}

	if ( $class )
		echo 'class="' . $class . '"';
}

if ( ! function_exists( 'thesecretworld_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * To override this walker in a child theme without modifying the comments template
 * simply create your own thesecretworld_comment(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since The Secret World 1.0
 */
function thesecretworld_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'thesecretworld' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( 'Edit', 'thesecretworld' ), '<span class="edit-link">', '</span>' ); ?></p>
	<?php
			break;
		default :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment">
			<footer class="comment-meta">
				<div class="comment-author vcard">
					<?php
						$avatar_size = 39;
						if ( '0' != $comment->comment_parent )
							$avatar_size = 39;

						echo get_avatar( $comment, $avatar_size );

						/* translators: 1: comment author, 2: date and time */
						printf( __( '<div class="comment-author-name">%1$s <span class="on">on&nbsp;</span></div>', 'thesecretworld' ),
							sprintf( '<span class="fn">%s</span>', get_comment_author_link() ));
					?>

					<?php edit_comment_link( __( 'Edit', 'thesecretworld' ), '<span class="edit-link">', '</span>' ); ?>
				</div><!-- .comment-author .vcard -->
				<div class="comment-date">
				<?php 

				printf( __('%1$s <span class="says">said:</span>', 'thesecretworld' ), sprintf( '<a href="%1$s" class="date"><time pubdate datetime="%2$s">%3$s</time></a>',
								esc_url( get_comment_link( $comment->comment_ID ) ),
								get_comment_time( 'c' ),
								/* translators: 1: date, 2: time */
								sprintf( __( '%1$s at %2$s', 'thesecretworld' ), get_comment_date(), get_comment_time() )
							));

				?>
				</div>

				<?php if ( $comment->comment_approved == '0' ) : ?>
					<em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'thesecretworld' ); ?></em>
					<br />
				<?php endif; ?>

			</footer>

			<div class="comment-content"><?php comment_text(); ?></div>

			<div class="reply">
				<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply <span>&darr;</span>', 'thesecretworld' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div><!-- .reply -->
		<div class="clear"></div>
		</article><!-- #comment-## -->
	<?php
			break;
	endswitch;
}
endif; // ends check for thesecretworld_comment()

if ( ! function_exists( 'thesecretworld_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 * Create your own thesecretworld_posted_on to override in a child theme
 *
 * @since The Secret World 1.0
 */
function thesecretworld_posted_on() {
	printf( __( '<span class="sep">Posted on </span><a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s" pubdate>%4$s</time></a><span class="by-author"> <span class="sep"> by </span> <span class="author vcard"><a class="url fn n" href="%5$s" title="%6$s" rel="author">%7$s</a></span></span>', 'thesecretworld' ),
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
		sprintf( esc_attr__( 'View all posts by %s', 'thesecretworld' ), get_the_author() ),
		esc_html( get_the_author() )
	);
}
endif;

/**
 * Adds two classes to the array of body classes.
 * The first is if the site has only had one author with published posts.
 * The second is if a singular post being displayed
 *
 * @since The Secret World 1.0
 */
function thesecretworld_body_classes( $classes ) {

	if ( ! is_multi_author() ) {
		$classes[] = 'single-author';
	}

	if ( is_singular() && ! is_home() && ! is_page_template( 'showcase.php' ) && ! is_page_template( 'sidebar-page.php' ) )
		$classes[] = 'singular';

	return $classes;
}
add_filter( 'body_class', 'thesecretworld_body_classes' );



/**
 * Human Equation modifications
 *
 * @since tsw 1.0
 */


/* Image sizes - HE */
add_image_size( 'article-home', '277', '153', true );
add_image_size( 'home-image', '604', '355', true );
add_image_size( 'home-thumb', '67', '71', true );
add_image_size( 'recent-medias', '212', '120', true );

/* Post excerpts length - HE */
function custom_excerpt_length( $length ) {
	return 50;
}
add_filter( 'excerpt_length', 'custom_excerpt_length', 999 );

/* Post excerpts link from manual excerpt - HE */
function excerpt_read_more_link($output) {
 global $post;
 return $output . '<a href="'. get_permalink($post->ID) . '" class="post-excerpt-more">Read more...</a>';
}
add_filter('the_excerpt', 'excerpt_read_more_link');

/* Add custom profile images - HE */
add_filter( 'avatar_defaults', 'newgravatar' );
function newgravatar ($avatar_defaults) {
    $dragon_avatar = get_bloginfo('template_directory') . '/images/dragon-login-logo.jpg';
    $avatar_defaults[$dragon_avatar] = "Dragon";
    $templar_avatar = get_bloginfo('template_directory') . '/images/templar-login-logo.jpg';
    $avatar_defaults[$templar_avatar] = "Templar";
    $illuminati_avatar = get_bloginfo('template_directory') . '/images/illuminati-login-logo.jpg';
    $avatar_defaults[$illuminati_avatar] = "Illuminati";
    return $avatar_defaults;
}